<!--新增修改页面-->
<template>
  <div class="function-page">
    <div class="title-box">
      <el-page-header @back="closePage" :content="title" />
    </div>
    <div class="form-content">
      <el-descriptions title="巡检任务详情" :column="2" border :labelStyle="{ 'width': '10%' }">
        <el-descriptions-item label="巡检任务名称" :span="2">{{ formData.planName }}</el-descriptions-item>
        <el-descriptions-item label="巡检类型">
          {{ dictionaryEscape(inspectionTypeOpt, formData.taskType + '') }}
        </el-descriptions-item>
        <el-descriptions-item label="任务时间">{{ formData.taskDate }}</el-descriptions-item>
        <el-descriptions-item label="巡检内容" :span="2">{{ formData.taskContent }}</el-descriptions-item>
        <el-descriptions-item label="巡检设备">
          <template>
            <el-tag v-for="(item, index) in formData.taskDetailsDto" size="medium" :key="index" :effect="item.productId === formData.productId ? 'dark' : (item.isHover ? 'light' : 'plain')
              " :disable-transitions="false" @mouseenter.native="item.isHover = true"
              style="margin-right: 5px;" @mouseleave.native="item.isHover = false" @click="equipClick(item)">
              {{ item.productName }}
            </el-tag>
          </template>
        </el-descriptions-item>
      </el-descriptions>
      <div class="equip-table-content" style="margin-top: 10px;">
        <template v-if="formData.taskDetailsDto.length">
          <!--     设备列表     -->
          <DeviceList :productId="formData.productId" ref="deviceListRef" :resultDto="resultDto" :taskId="rowInfo.id" />
        </template>
      </div>
      <div class="btn-content">
        <!-- <el-button type="primary" @click="handleSaveData" size="medium">
          保 存
        </el-button> -->
        <el-button @click="closePage" size="medium">取 消</el-button>
      </div>
    </div>

    <!--  选择设备弹层  -->
    <InspectionEquipmentDialog :inspectEquipDialog.sync="inspectEquipDialog"
      :taskDetailsDto.sync="formData.taskDetailsDto" @equipSelect="equipSelect" />
  </div>
</template>

<script>
import {
  deviceInspectionPlanAdd,
  deviceInspectionPlanDetails,
  deviceInspectionPlanEdit,
  addOrUpdatePlan,
  getTaskDetailsById,
  removeProductById
} from '@/api/device/resourceInspection/resourceInspection'

import InspectionEquipmentDialog from './components/InspectionEquipmentDialog.vue'
import DeviceList from './components/DeviceList.vue'
import { dictionaryEscape } from '@/utils/dictionary'

export default {
  name: 'AddModifyDialog',
  components: { DeviceList, InspectionEquipmentDialog },
  props: {
    rowInfo: {
      default: _ => ({}),
      type: Object
    },
    inspectionTypeOpt: {
      default: _ => ([]),
      type: Array
    }
  },
  computed: {
    resultDto() {
      return this.formData.taskDetailsDto.find(i => i.productId === this.formData.productId)
    }
  },
  data() {
    return {
      title: '标题',
      formData: {
        productId: '', // 选中的设备Id（前端自定义字段）
        // productTable: [], // 选中的设备列表（前端自定义字段）
        taskDetailsDto: []
      },
      inspectEquipDialog: false // 选择设备弹层显隐
    }
  },
  created() {
    this.openPage()
  },
  methods: {
    dictionaryEscape,
    // 弹层打开
    openPage() {
      console.log(this.rowInfo);
      
      let title = ''
      if (this.rowInfo.id) {
        title = '编辑'
        this.getDetails(this.rowInfo.id)
      } else {
        title = '新增'
      }
      this.title = `${title}巡检任务`
    },

    // 弹层关闭
    closePage() {
      this.$emit('closePage')
      this.formData = this.$options.data().formData
    },

    // 获取详情
    async getDetails(id) {
      const { taskDetailsDto, ...formData } = (await getTaskDetailsById(id)).value || {}
      this.formData = {
        ...formData,
        productId: taskDetailsDto[0]?.productId || '',
        taskDetailsDto: taskDetailsDto.map(i => ({ ...i, isHover: false }))
      }
    },

    // 设备选择后
    equipSelect() {
      this.$refs.deviceListRef && this.$refs.deviceListRef.calcTableHeight()
      if (!this.formData.productId) {
        this.formData.productId = this.formData.taskDetailsDto[0]?.productId || ''
      }
    },

    // 设备分类点击后
    equipClick(item) {
      if (!item.productId) return
      this.$refs.deviceListRef && this.$refs.deviceListRef.calcTableHeight()
      this.formData.productId = item.productId
    },

    // 设备分类关闭后
    equipClose(item, index) {
      console.log(item);

      this.$confirm(`确认删除${item.productName}？`, '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(_ => {
        removeProductById(item.productId).then(res => {
          if (res.state) {
            this.$message.success('产品删除成功！')
            this.formData.taskDetailsDto.splice(index, 1)
            if (item.productId === this.formData.productId) {
              this.formData.productId = this.formData.taskDetailsDto[0]?.productId || ''
              this.$refs.deviceListRef && this.$refs.deviceListRef.calcTableHeight()
            }
          }
        })
      }).catch(_ => _)
    },

    showDialog(dialog) {
      this[dialog] = true
    }
  }
}
</script>
<style lang="scss" scoped>
.function-page {
  display: flex;
  flex-direction: column;
  height: 100%;
  row-gap: 10px;

  .title-box {
    background-color: #fff;
    height: 60px;
    display: flex;
    align-items: center;
    box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.1);
    padding: 0 20px;
  }

  .form-content {
    flex: 1;
    display: flex;
    flex-direction: column;
    padding: 30px 20px 20px;
    background-color: #fff;
    box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.1);
    position: relative;
    box-sizing: border-box;

    ::v-deep .el-form {


      .tage-content {
        display: flex;
        margin-top: 2px;
        column-gap: 10px;
        row-gap: 10px;
        flex-wrap: wrap;

        .el-button {
          span {
            font-size: 12px;
          }
        }

        .el-tag {
          user-select: none;
          cursor: pointer;
        }
      }
    }

    .equip-table-content {
      flex: 1;
    }

    .btn-content {
      display: flex;
      justify-content: right;
      margin-top: 20px;
    }
  }

}
</style>
